@@ -3,7 +3,7 @@
 //  PRICE
 //
 //  Created by Riccardo Mottola on Thu Dec 12 2002.
-//  Copyright (c) 2003 Carduus. All rights reserved.
+//  Copyright (c) 2002-2007 Carduus. All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify it under the terms of the version 2 of the GNU General Public License as published by the Free Software Foundation.
 // This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
@@ -18,6 +18,7 @@
 @interface MyDocument : NSDocument
 {
     PRWindowController *windowController;
+    NSPrintInfo        *printInfo;
     @private PRImage   *activeImage;
     @private PRImage   *oldImage;
 }
@@ -26,7 +27,8 @@
 - (NSView *)view;
 - (PRImage *)activeImage;
 - (void)setActiveImage: (PRImage *)theImage;
-- (void)makeGrayscale :(id)sender;
+- (void)makeGrayscale :(int)method :(id)sender;
+- (void)makeInverse :(id)sender;
 - (void)makeDFT :(id)sender;
 - (void)makeDFTLowPass :(BOOL)autoRange :(float) bandPassFreq :(float) bandStopFreq :(PRCProgress *)prPan;
 - (void)makeDFTHighPass :(BOOL)autoRange :(float) bandPassFreq :(float) bandStopFreq :(PRCProgress *)prPan;
@@ -46,4 +48,6 @@
 - (void)makeCrop :(int)sizeTop :(int)sizeBottom :(int)sizeLeft :(int)sizeRight;
 - (void)restoreLastImage;
 - (void)saveCurrentImage;
+- (void)setPrintInfo:(NSPrintInfo *)anObject;
+- (NSPrintInfo *)printInfo;
 @end
