@@ -10,6 +10,7 @@
 // This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 
 #import "PRCEqualize.h"
+#import "PREqualize.h"
 #import "MyDocument.h"
 
 @implementation PRCEqualize
@@ -23,7 +24,16 @@
 
 - (IBAction)equalizeOK:(id)sender
 {
-    [[[NSDocumentController sharedDocumentController] currentDocument] makeEqualization:nil];
+    int index;
+    int space;
+    
+    index = [colorSpaceChoice indexOfSelectedItem];
+    if (index == 0)
+        space = COLOR_SPACE_RGB;
+    else if (index == 1)
+        space = COLOR_SPACE_YUV;
+
+    [[[NSDocumentController sharedDocumentController] currentDocument] makeEqualization :space :nil];
     if ([[NSApp delegate] prefClosePanels])
         [equalWindow performClose:nil];
 }
