@@ -11,11 +11,14 @@
 #import <AppKit/AppKit.h>
 #import "PRImage.h"
 
+#define COLOR_SPACE_RGB 1
+#define COLOR_SPACE_YUV 2
+
 
 @interface PREqualize : NSObject {
 
 }
 
-- (PRImage *)equalizeImage:(PRImage *)srcImage;
+- (PRImage *)equalizeImage:(PRImage *)srcImage :(int)space;
 
 @end
