@@ -30,6 +30,6 @@
 - (void)scaleImage;
 - (void)setImageToDraw:(PRImage *)image;
 - (void)setImageInfo:(PRImage *)image;
-- (NSView *)view;
+- (PRImageView *)view;
 
 @end
